==> zio-aws-iot1clickdevices_2.13-5.17.125.1-sources.jar: zio/aws/iot1clickdevices/model/InitiateDeviceClaimResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InitiateDeviceClaimResponse(state: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse = {
    import InitiateDeviceClaimResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
      .builder()
      .optionallyWith(
        state.map(value => __string.unwrap(value): java.lang.String)
      )(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse
      .wrap(buildAwsValue())
}
object InitiateDeviceClaimResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse =
      zio.aws.iot1clickdevices.model
        .InitiateDeviceClaimResponse(state.map(value => value))
    def state: Option[__string]
    def getState: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ) extends zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly {
    override val state: Option[__string] = scala
      .Option(impl.state())
      .map(value => zio.aws.iot1clickdevices.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ): zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.146.2-sources.jar: zio/aws/iot1clickdevices/model/InitiateDeviceClaimResponse.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InitiateDeviceClaimResponse(state: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse = {
    import InitiateDeviceClaimResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
      .builder()
      .optionallyWith(state.map(value => value: java.lang.String))(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly =
    zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse
      .wrap(buildAwsValue())
}
object InitiateDeviceClaimResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse =
      zio.aws.iot1clickdevices.model
        .InitiateDeviceClaimResponse(state.map(value => value))
    def state: Option[__string]
    def getState: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ) extends zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly {
    override val state: Option[__string] =
      scala.Option(impl.state()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimResponse
  ): zio.aws.iot1clickdevices.model.InitiateDeviceClaimResponse.ReadOnly =
    new Wrapper(impl)
}
